@@ -112,6 +112,11 @@ def prepare_test(production_name, job_name, dependent_input=None):
     if "bk_query" in job_data["input"] or "transform_ids" in job_data["input"]:
         if dependent_input is not None:
             prodrun_conf["input"]["files"] = [dependent_input]
+            if "LFN:" in dependent_input:
+                (out_dir / "pool_xml_catalog.xml").write_text(
+                    pool_xml_catalog([dependent_input])
+                )
+                prodrun_conf["input"]["xml_file_catalog"] = "pool_xml_catalog.xml"
         else:
             response = requests.post(
                 f"{LBAPI_HOST}/pipelines/lfns/",
